@@ -8,12 +8,14 @@ use warnings;
 use Mojo::Base qw(Mojolicious::Plugin);
 use JavaScript::Console;
 
-our $VERSION = 0.02;
+our $VERSION = '0.03';
 
 sub register {
     my ($plugin, $mojo, $param) = @_;
 
-    my $console = JavaScript::Console->new( %{ $param || {} } );
+    $param = {} if 'HASH' ne ref $param;
+
+    my $console = JavaScript::Console->new( %{ $param } );
 
     $mojo->helper(
         'console' => sub {
@@ -36,7 +38,7 @@ Mojolicious::Plugin::JavaScript::Console - use the JavaScript console from Mojol
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
